/**
 * Copyright 2005 Darren L. Spurgeon
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ajaxtags.servlets;

import java.io.PrintWriter;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.Action;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

/**
 * Abstract class that can be extended for application-specific Struts action classes.
 *
 * @author Darren Spurgeon
 * @version $Revision: 1.3 $ - $Date: 2005/10/20 17:29:51 $
 */
public abstract class BaseAjaxAction extends Action {

  /**
   * @see Action#execute(ActionMapping, ActionForm, HttpServletRequest, HttpServletResponse)
   */
  public final ActionForward execute(
      ActionMapping mapping, ActionForm form, HttpServletRequest request,
      HttpServletResponse response) throws Exception {

    String xml = null;
    try {
      xml = getXmlContent(mapping, form, request, response);
    } catch (Exception ex) {
      // Send back a 500 error code.
      response.sendError(HttpServletResponse.SC_INTERNAL_SERVER_ERROR, "Can not create response");
      return null;
    }

    // Set content to xml
    response.setContentType("text/xml; charset=UTF-8");
    response.setHeader("Cache-Control", "no-cache");
    PrintWriter pw = response.getWriter();
    pw.write(xml);
    pw.close();

    return null;
  }

  /**
   * Each child class should override this method to generate the specific XML content necessary for
   * each AJAX action.
   *
   * @param mapping
   * @param form
   * @param request the {@javax.servlet.http.HttpServletRequest} object
   * @param response the {@javax.servlet.http.HttpServletResponse} object
   * @return a {@java.lang.String} representation of the XML response/content
   * @throws Exception
   */
  public abstract String getXmlContent(
      ActionMapping mapping, ActionForm form, HttpServletRequest request,
      HttpServletResponse response) throws Exception;

}
