/**
 * Copyright 2005 Darren L. Spurgeon
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ajaxtags.tags;

import java.io.IOException;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.tagext.TagSupport;

import org.apache.commons.lang.StringUtils;
import org.apache.taglibs.standard.lang.support.ExpressionEvaluatorManager;

/**
 * Tag handler for the HTML Content AJAX tag.
 *
 * @author Darren Spurgeon
 * @version $Revision: 1.10 $ $Date: 2006/04/12 00:15:44 $
 */
public class AjaxHtmlContentTag extends TagSupport {

  private String var;

  private String attachTo;

  private String baseUrl;

  private String source;

  private String sourceClass;

  private String target;

  private String parameters;

  private String eventType;

  private String postFunction;

  private String preFunction;

  private String errorFunction;

  public String getBaseUrl() {
    return baseUrl;
  }

  public void setBaseUrl(String baseUrl) {
    this.baseUrl = baseUrl;
  }

  public String getErrorFunction() {
    return errorFunction;
  }

  public void setErrorFunction(String errorFunction) {
    this.errorFunction = errorFunction;
  }

  public String getEventType() {
    return eventType;
  }

  public void setEventType(String eventType) {
    this.eventType = eventType;
  }

  public String getVar() {
    return var;
  }

  public void setVar(String var) {
    this.var = var;
  }

  public String getAttachTo() {
    return attachTo;
  }
  
  public void setAttachTo(String attachTo) {
    this.attachTo = attachTo;
  }

  public String getParameters() {
    return parameters;
  }

  public void setParameters(String parameters) {
    this.parameters = parameters;
  }
  
  public String getPreFunction() {
    return preFunction;
  }
  
  public void setPreFunction(String preFunction) {
    this.preFunction = preFunction;
  }

  public String getPostFunction() {
    return postFunction;
  }

  public void setPostFunction(String postFunction) {
    this.postFunction = postFunction;
  }

  public String getSource() {
    return source;
  }

  public void setSource(String source) {
    this.source = source;
  }

  public String getSourceClass() {
    return sourceClass;
  }

  public void setSourceClass(String sourceClass) {
    this.sourceClass = sourceClass;
  }

  public String getTarget() {
    return target;
  }

  public void setTarget(String target) {
    this.target = target;
  }

  public int doStartTag() throws JspException {
    // Required Properties
    this.baseUrl = (String) ExpressionEvaluatorManager.evaluate("baseUrl", this.baseUrl,
        String.class, this, super.pageContext);
    this.parameters = (String) ExpressionEvaluatorManager.evaluate("parameters", this.parameters,
        String.class, this, super.pageContext);
    this.target = (String) ExpressionEvaluatorManager.evaluate("target", this.target, String.class,
        this, super.pageContext);

    // Optional Properties
    if (this.var != null) {
      this.var = (String) ExpressionEvaluatorManager.evaluate("var", this.var, String.class, this,
          super.pageContext);
    }
    if (this.attachTo != null) {
      this.attachTo = (String) ExpressionEvaluatorManager.evaluate("attachTo", this.attachTo,
          String.class, this, super.pageContext);
    }
    if (this.source != null) {
      this.source = (String) ExpressionEvaluatorManager.evaluate("source", this.source,
          String.class, this, super.pageContext);
    }
    if (this.sourceClass != null) {
      this.sourceClass = (String) ExpressionEvaluatorManager.evaluate("sourceClass",
          this.sourceClass, String.class, this, super.pageContext);
    }
    if (this.eventType != null) {
      this.eventType = (String) ExpressionEvaluatorManager.evaluate("eventType", this.eventType,
          String.class, this, super.pageContext);
    }
    if (this.preFunction != null) {
      this.preFunction = (String) ExpressionEvaluatorManager.evaluate("preFunction",
          this.preFunction, String.class, this, super.pageContext);
    }
    if (this.postFunction != null) {
      this.postFunction = (String) ExpressionEvaluatorManager.evaluate("postFunction",
          this.postFunction, String.class, this, super.pageContext);
    }
    if (this.errorFunction != null) {
      this.errorFunction = (String) ExpressionEvaluatorManager.evaluate("errorFunction",
          this.errorFunction, String.class, this, super.pageContext);
    }
    return SKIP_BODY;
  }

  public int doEndTag() throws JspException {
    OptionsBuilder options = new OptionsBuilder();
    if (this.source != null) {
      options.add("source", this.source, true);
    } else {
      options.add("sourceClass", this.sourceClass, true);
    }
    options
        .add("parameters", this.parameters, true)
        .add("target", this.target, true);
    if (this.eventType != null)
      options.add("eventType", this.eventType, true);
    if (this.preFunction != null)
      options.add("preFunction", this.preFunction, false);
    if (this.postFunction != null)
      options.add("postFunction", this.postFunction, false);
    if (this.errorFunction != null)
      options.add("errorFunction", this.errorFunction, false);

    StringBuffer script = new StringBuffer();
    script.append("<script type=\"text/javascript\">\n");

    if (StringUtils.isNotEmpty(this.attachTo)) {
      script.append(this.attachTo).append(".");
      if (StringUtils.isNotEmpty(this.var)) {
        script.append(this.var);
      } else {
        script.append("aj_").append(this.source);
      }
    } else if (StringUtils.isNotEmpty(this.var)) {
      script.append("var ").append(this.var);
    } else {
      script.append("var aj_").append(this.source);
    }

    script
        .append(" = new AjaxJspTag.HtmlContent(\n")
        .append("\"")
        .append(this.baseUrl)
        .append("\", {\n")
        .append(options.toString())
        .append("});\n")
        .append("</script>\n\n");

    JspWriter writer = pageContext.getOut();
    try {
      writer.println(script);
    } catch (IOException e) {
      throw new JspException(e.getMessage());
    }
    return EVAL_PAGE;
  }

  public void release() {
    this.var = null;
    this.attachTo = null;
    this.baseUrl = null;
    this.source = null;
    this.sourceClass = null;
    this.target = null;
    this.parameters = null;
    this.eventType = null;
    this.postFunction = null;
    this.preFunction = null;
    this.errorFunction = null;
    super.release();
  }

}
